#dashboard {
  display: flex;
  flex-wrap: wrap;
  justify-content: center;
}
#dashboard .panel {
  padding: 20px;
  min-width: 300px;
}
#dashboard .panel h2 {
  text-align: center;
}
#dashboard .panel svg text {
  fill: inherit; /* override Fava's stylesheet */
}
#dashboard a {
  color: light-dark(#333, #d7dce2); /* --heading-color from fava */
}

/* set panel min-width to 100% on screens < 802px (navbar + padding + 2*300px) */
@media (max-width: 802px) {
  #dashboard .panel {
    min-width: 100%;
  }
}
